@@ -341,6 +341,10 @@ impl<T> AudioBufferRef<T> {
             ));
         }
 
+        if self.plane_size() == 0 {
+            return Ok(&[]);
+        }
+
         unsafe {
             Ok(slice::from_raw_parts(
                 (*self.audio_buffer.planes.add(plane as usize)) as *const u8,
@@ -470,6 +474,10 @@ impl<'a> AudioBufferRef<&'a mut gst::BufferRef> {
             ));
         }
 
+        if self.plane_size() == 0 {
+            return Ok(&mut []);
+        }
+
         unsafe {
             Ok(slice::from_raw_parts_mut(
                 (*self.audio_buffer.planes.add(plane as usize)) as *mut u8,
