@@ -2,6 +2,8 @@
 
 #![allow(clippy::cast_ptr_alignment)]
 
+mod audio_base_sink;
+mod audio_base_src;
 mod audio_decoder;
 mod audio_encoder;
 mod audio_sink;
@@ -11,6 +13,8 @@ pub mod prelude {
     #[doc(hidden)]
     pub use gst_base::subclass::prelude::*;
 
+    pub use super::audio_base_sink::AudioBaseSinkImpl;
+    pub use super::audio_base_src::AudioBaseSrcImpl;
     pub use super::audio_decoder::{AudioDecoderImpl, AudioDecoderImplExt};
     pub use super::audio_encoder::{AudioEncoderImpl, AudioEncoderImplExt};
     pub use super::audio_sink::{AudioSinkImpl, AudioSinkImplExt};
